/*
 * LED Core
 *
 * Copyright 2005 Openedhand Ltd.
 *
 * Author: Richard Purdie <rpurdie@openedhand.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 */
#ifndef __LEDS_H_INCLUDED
#define __LEDS_H_INCLUDED

#include <linux/rwsem.h>
#include <linux/leds.h>

static inline void led_set_color(struct led_classdev *led_cdev,
					enum led_brightness value)
{
	led_cdev->color = value;
	if (!(led_cdev->flags & LED_SUSPENDED))
		led_cdev->color_set(led_cdev, value);
}

static inline int led_get_color(struct led_classdev *led_cdev)
{
	return led_cdev->color;
}
static inline void led_set_blink(struct led_classdev *led_cdev,
					enum led_brightness value)
{
	led_cdev->blink = value;
        led_cdev->blink_set_3g(led_cdev, value);
}

static inline int led_get_brightness(struct led_classdev *led_cdev)
{
	return led_cdev->brightness;
}

void led_init_core(struct led_classdev *led_cdev);
void led_stop_software_blink(struct led_classdev *led_cdev);
void led_set_brightness_nopm(struct led_classdev *led_cdev,
				enum led_brightness value);
void led_set_brightness_nosleep(struct led_classdev *led_cdev,
				enum led_brightness value);

extern struct rw_semaphore leds_list_lock;
extern struct list_head leds_list;
extern struct list_head trigger_list;

#endif	/* __LEDS_H_INCLUDED */
